@@ -1,6 +1,7 @@
 import igraph as ig
 import numpy as np
-import sys, random, os, time
+from pathlib import Path
+import sys, random, os, time, gzip, pickle
 try:
     from ctns.generator import generate_network, init_infection
     from ctns.steps import step
@@ -10,8 +11,7 @@ except ImportError as e:
     from steps import step
     from utility import dump_network, compute_IR
 
-def run_simulation(path,
-    n_of_families = 500,
+def run_simulation(n_of_families = 500,
     use_steps = True,
     number_of_steps = 150,
     incubation_days = 5,
@@ -26,17 +26,16 @@ def run_simulation(path,
     policy_test = "Random",
     contact_tracking_efficiency = 0.8,
     use_random_seed = None,
-    seed = None):
+    seed = None,
+    dump = False,
+    path = None):
 
     """
-    Execute the simulation and dump resulting networks
+    Execute the simulation and dump/return resulting networks
 
     Parameters
     ----------
     
-    path:string
-        The path to the folder where the networks will be saved
-
     n_of_families: int
         Number of families in the network
         
@@ -56,7 +55,7 @@ def run_simulation(path,
         Day index from when social distancing measures are applied
 
     restriction_duration: int
-        How many days the social distancing last. Use -1 to make the restriction last till the end of the simulation
+        How many days the social distancing last. Use 0 to make the restriction last till the end of the simulation
 
     social_distance_strictness: int
         How strict from 0 to 4 the social distancing measures are. 
@@ -87,10 +86,18 @@ def run_simulation(path,
     seed: int
         The random seed value
 
+    dump: bool
+        If true dump networks to file, otherwise return the networks list
+        NB, if network simulation is too heavy, the dump can crash
+
+    path:string
+        The path to the folder where the networks will be saved
+
     Return
     ------
 
-    None. It saves the dumps of the networks in the path folder
+    nets:list
+        List of nets of the simulation
 
     """
     # generate new edges
@@ -105,17 +112,16 @@ def run_simulation(path,
 
     # clear folder
     file_list = os.listdir(path)
-
+    
     for item in file_list:
         if item.endswith(".pickle"):
             os.remove(os.path.join(path, item))
+    
 
     # init network
     G = generate_network(n_of_families)
     infection_rate = compute_IR(G, R_0, infection_duration, incubation_days)
     init_infection(G, n_initial_infected_nodes)
-    dump_network(G, path + "/initial_network")
-
     nets = list()
 
     if use_steps:
@@ -123,8 +129,7 @@ def run_simulation(path,
             report, net= step(G, sim_index, incubation_days, infection_duration, infection_rate,
                              initial_day_restriction, restriction_duration, social_distance_strictness, 
                              restriction_decreasing, nets, n_test, policy_test, contact_tracking_efficiency)
-            nets.append(net)
-            dump_network(G, path + "/network{}".format(sim_index))
+            nets.append(net.copy())
     else:
         exposed = n_initial_infected_nodes
         infected = 0
@@ -133,15 +138,23 @@ def run_simulation(path,
             report, net= step(G, sim_index, incubation_days, infection_duration, infection_rate,
                              initial_day_restriction, restriction_duration, social_distance_strictness, 
                              restriction_decreasing, nets, n_test, policy_test, contact_tracking_efficiency)
-            nets.append(net)
-            dump_network(G, path + "/network{}".format(sim_index))
+            nets.append(net.copy())
             sim_index += 1
             infected = report["I"]
             exposed = report["E"]
 
             if infected + exposed == 0:
                 break
-
+    if dump:
+        try:
+            with open(Path(path + "/nets.pickle"), "wb") as f:
+                pickle.dump(nets, f)
+        except:
+            print("Simulation is too big to be dumped, please use the return value of the function for analysis")
+            sys.exit(-1)
+    
+    return nets
+    
     print("\n Simulation ended successfully \n You can find the dumped networks in the choosen folder \n")
 
 def main():
@@ -162,6 +175,7 @@ def main():
     contact_tracking_efficiency = None
     use_random_seed = None
     seed = None
+    dump = True
     path = None
 
     user_interaction = int(input("Press 0 to load the default values or 1 to manually input the configuration for the simulation: "))
@@ -174,7 +188,7 @@ def main():
         incubation_days = int(input("Please insert the disease incubation duration: "))
         infection_duration = int(input("Please insert the disease duration: "))
         initial_day_restriction = int(input("Please insert the step index from which the social distance is applied: "))
-        restriction_duration = int(input("Please insert the number of days which the social distance last. Insert -1 to make the restriction last for all the simulation: "))
+        restriction_duration = int(input("Please insert the number of days which the social distance last. Insert 0 to make the restriction last for all the simulation: "))
         social_distance_strictness = int(input("Please insert a value between 0 and 4 to set the social distance strictness: "))
         restriction_decreasing = int(input("Press 0 to make the strictness of the social distance decrease during the simulation or 1 to keep it fixed: "))
         n_initial_infected_nodes = int(input("Please insert the number of initial infected individuals: "))
@@ -222,19 +236,19 @@ def main():
         if contact_tracking_efficiency < 0 or contact_tracking_efficiency > 1:
             print("Invalid contact tracing efficiency")
             sys.exit()
-        if restriction_duration < -1:
+        if restriction_duration < 0:
             print("Invalid restriction restriction_duration")
             sys.exit()
-        if     restriction_duration == -1:
+        if restriction_duration == 0:
             restriction_decreasing = False
             restriction_duration = False        
 
-        run_simulation(path, n_of_families, use_steps, number_of_steps, incubation_days, infection_duration,
+        run_simulation(n_of_families, use_steps, number_of_steps, incubation_days, infection_duration,
             initial_day_restriction, restriction_duration, social_distance_strictness, restriction_decreasing,
-            n_initial_infected_nodes, R_0, n_test, policy_test, contact_tracking_efficiency, use_random_seed, seed, path)
+            n_initial_infected_nodes, R_0, n_test, policy_test, contact_tracking_efficiency, use_random_seed, seed, dump, path)
     else:
         path = input("Please insert the path to a folder for dumps: ")
-        run_simulation(path = path)
+        run_simulation(path = path, dump = True)
 
 if __name__ == "__main__":
     main()
\ No newline at end of file
